Embedded source for the Leo standard library.
Compiler and tooling crates depend on this to inject std into every
Leo build without requiring users to declare it in program.json.
Constants
- LIBRARY_
NAME - The Leo identifier under which the standard library is exposed
(
std::foo(...)).
Functions
- entry_
source - Entry source of the standard library (contents of
lib.leo). - library_
name - The Leo identifier under which the standard library is exposed.
- modules
- Submodule sources, returned as
(virtual_path, source)pairs.